Scenarios
*********

Scenarios describe **what you need**. They define the tests and the necessary devices for them.

This BalderHub package only provides one single scenario class:

.. autoclass:: balderhub.unit.scenarios.ScenarioUnit
    :members:
    :private-members:
